Date: prev next · Thread: first prev next last
2013 Archives by date, by thread · List index


Hi,

I have submitted a patch for review:

    https://gerrit.libreoffice.org/3435

To pull it, you can do:

    git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/35/3435/1

Fix typos: HEIGTH -> HEIGHT and WEIGTH -> WEIGHT

Change-Id: Ie5dc62bf535360cde8a5ccd6f8be3965ff48739c
---
M xmloff/inc/xmloff/PageMasterStyleMap.hxx
M xmloff/inc/xmloff/xmltoken.hxx
M xmloff/source/chart/PropertyMap.hxx
M xmloff/source/core/xmltoken.cxx
M xmloff/source/style/PageMasterExportPropMapper.cxx
M xmloff/source/style/PageMasterStyleMap.cxx
M xmloff/source/style/PagePropertySetContext.cxx
M xmloff/source/style/XMLFootnoteSeparatorExport.cxx
M xmloff/source/style/XMLFootnoteSeparatorImport.cxx
9 files changed, 11 insertions(+), 11 deletions(-)



diff --git a/xmloff/inc/xmloff/PageMasterStyleMap.hxx b/xmloff/inc/xmloff/PageMasterStyleMap.hxx
index c1c6d31..c3a8392 100644
--- a/xmloff/inc/xmloff/PageMasterStyleMap.hxx
+++ b/xmloff/inc/xmloff/PageMasterStyleMap.hxx
@@ -150,8 +150,8 @@
 #define CTF_PM_FOOTERMARGINLEFT         (CTF_PM_FOOTERFLAG|CTF_PM_MARGINLEFT)
 #define CTF_PM_FOOTERMARGINRIGHT        (CTF_PM_FOOTERFLAG|CTF_PM_MARGINRIGHT)
 
-#define CTF_PM_FTN_HEIGTH               (XML_PM_CTF_START + 0x0060)
-#define CTF_PM_FTN_LINE_WEIGTH          (XML_PM_CTF_START + 0x0061)
+#define CTF_PM_FTN_HEIGHT               (XML_PM_CTF_START + 0x0060)
+#define CTF_PM_FTN_LINE_WEIGHT          (XML_PM_CTF_START + 0x0061)
 #define CTF_PM_FTN_LINE_COLOR           (XML_PM_CTF_START + 0x0062)
 #define CTF_PM_FTN_LINE_WIDTH           (XML_PM_CTF_START + 0x0063)
 #define CTF_PM_FTN_LINE_ADJUST          (XML_PM_CTF_START + 0x0064)
diff --git a/xmloff/source/chart/PropertyMap.hxx b/xmloff/source/chart/PropertyMap.hxx
index 6363fa2..e924b7f 100644
--- a/xmloff/source/chart/PropertyMap.hxx
+++ b/xmloff/source/chart/PropertyMap.hxx
@@ -192,7 +192,7 @@
     // errorbars properties (chart2)
     MAP_ENTRY_ODF_EXT( "PositiveError", CHART, XML_ERROR_LOWER_LIMIT, XML_TYPE_DOUBLE),
     MAP_ENTRY_ODF_EXT( "NegativeError", CHART, XML_ERROR_UPPER_LIMIT, XML_TYPE_DOUBLE),
-    MAP_ENTRY_ODF_EXT( "Weigth", CHART, XML_ERROR_STANDARD_WEIGTH, XML_TYPE_DOUBLE),
+    MAP_ENTRY_ODF_EXT( "Weight", CHART, XML_ERROR_STANDARD_WEIGHT, XML_TYPE_DOUBLE),
 
     // series/data-point properties
     MAP_SPECIAL( "DataCaption", CHART, XML_DATA_LABEL_NUMBER, XML_TYPE_NUMBER | 
MID_FLAG_MERGE_PROPERTY, XML_SCH_CONTEXT_SPECIAL_DATA_LABEL_NUMBER ),   // convert one constant
diff --git a/xmloff/source/core/xmltoken.cxx b/xmloff/source/core/xmltoken.cxx
index da73b16..264770d 100644
--- a/xmloff/source/core/xmltoken.cxx
+++ b/xmloff/source/core/xmltoken.cxx
@@ -3182,7 +3182,7 @@
         TOKEN( "horizontal-bar",               XML_HORIZONTAL_BAR ),
         TOKEN( "vertical-bar",                 XML_VERTICAL_BAR ),
 
-        TOKEN( "std-weight", XML_ERROR_STANDARD_WEIGTH ),
+        TOKEN( "std-weight", XML_ERROR_STANDARD_WEIGHT ),
 
 #if OSL_DEBUG_LEVEL > 0
         { 0, NULL, NULL,                       XML_TOKEN_END }
diff --git a/xmloff/source/style/PageMasterExportPropMapper.cxx 
b/xmloff/source/style/PageMasterExportPropMapper.cxx
index 72fcc67..db50eb6 100644
--- a/xmloff/source/style/PageMasterExportPropMapper.cxx
+++ b/xmloff/source/style/PageMasterExportPropMapper.cxx
@@ -292,7 +292,7 @@
         case CTF_PM_TEXTCOLUMNS:
             pThis->aTextColumnsExport.exportXML( rProperty.maValue );
             break;
-        case CTF_PM_FTN_LINE_WEIGTH:
+        case CTF_PM_FTN_LINE_WEIGHT:
             pThis->aFootnoteSeparatorExport.exportXML( pProperties, nIdx,
                                                        getPropertySetMapper());
             break;
diff --git a/xmloff/source/style/PageMasterStyleMap.cxx b/xmloff/source/style/PageMasterStyleMap.cxx
index 815c5e9..8726729 100644
--- a/xmloff/source/style/PageMasterStyleMap.cxx
+++ b/xmloff/source/style/PageMasterStyleMap.cxx
@@ -115,13 +115,13 @@
     PLMAP( "UserDefinedAttributes", XML_NAMESPACE_TEXT,     XML_XMLNS,                      
XML_TYPE_ATTRIBUTE_CONTAINER | MID_FLAG_SPECIAL_ITEM, 0 ),
 
 // footnote
-    PLMAP( "FootnoteHeight",            XML_NAMESPACE_STYLE,    XML_FOOTNOTE_MAX_HEIGHT, 
XML_TYPE_MEASURE, CTF_PM_FTN_HEIGTH ),
+    PLMAP( "FootnoteHeight",            XML_NAMESPACE_STYLE,    XML_FOOTNOTE_MAX_HEIGHT, 
XML_TYPE_MEASURE, CTF_PM_FTN_HEIGHT ),
     PLMAP( "FootnoteLineAdjust",        XML_NAMESPACE_STYLE,    XML__EMPTY,     
XML_TYPE_TEXT_HORIZONTAL_ADJUST|MID_FLAG_SPECIAL_ITEM,  CTF_PM_FTN_LINE_ADJUST ),
     PLMAP( "FootnoteLineColor",     XML_NAMESPACE_STYLE,    XML__EMPTY,     
XML_TYPE_COLOR|MID_FLAG_SPECIAL_ITEM,       CTF_PM_FTN_LINE_COLOR ),
     PLMAP( "FootnoteLineDistance",  XML_NAMESPACE_STYLE,    XML__EMPTY,     
XML_TYPE_MEASURE|MID_FLAG_SPECIAL_ITEM,CTF_PM_FTN_DISTANCE ),
     PLMAP( "FootnoteLineRelativeWidth", XML_NAMESPACE_STYLE,    XML__EMPTY,     
XML_TYPE_PERCENT8|MID_FLAG_SPECIAL_ITEM,    CTF_PM_FTN_LINE_WIDTH ),
     PLMAP( "FootnoteLineTextDistance", XML_NAMESPACE_STYLE, XML__EMPTY,     
XML_TYPE_MEASURE|MID_FLAG_SPECIAL_ITEM, CTF_PM_FTN_LINE_DISTANCE ),
-    PLMAP( "FootnoteLineWeight",        XML_NAMESPACE_STYLE,    XML_FOOTNOTE_SEP,   
XML_TYPE_MEASURE16|MID_FLAG_ELEMENT_ITEM,   CTF_PM_FTN_LINE_WEIGTH ),
+    PLMAP( "FootnoteLineWeight",        XML_NAMESPACE_STYLE,    XML_FOOTNOTE_SEP,   
XML_TYPE_MEASURE16|MID_FLAG_ELEMENT_ITEM,   CTF_PM_FTN_LINE_WEIGHT ),
     PLMAP( "FootnoteLineStyle",     XML_NAMESPACE_STYLE,    XML_EMPTY,  
XML_TYPE_STRING|MID_FLAG_ELEMENT_ITEM,  CTF_PM_FTN_LINE_STYLE ),
 
 // header
diff --git a/xmloff/source/style/PagePropertySetContext.cxx 
b/xmloff/source/style/PagePropertySetContext.cxx
index 7f194e1..7fa21ce 100644
--- a/xmloff/source/style/PagePropertySetContext.cxx
+++ b/xmloff/source/style/PagePropertySetContext.cxx
@@ -105,7 +105,7 @@
                                               rProperties );
         break;
 
-    case CTF_PM_FTN_LINE_WEIGTH:
+    case CTF_PM_FTN_LINE_WEIGHT:
         pContext = new XMLFootnoteSeparatorImport(
             GetImport(), nPrefix, rLocalName, rProperties,
             mxMapper->getPropertySetMapper(), rProp.mnIndex);
diff --git a/xmloff/source/style/XMLFootnoteSeparatorExport.cxx 
b/xmloff/source/style/XMLFootnoteSeparatorExport.cxx
index 761ffdc..89ebcf8 100644
--- a/xmloff/source/style/XMLFootnoteSeparatorExport.cxx
+++ b/xmloff/source/style/XMLFootnoteSeparatorExport.cxx
@@ -95,7 +95,7 @@
         case CTF_PM_FTN_LINE_DISTANCE:
             rState.maValue >>= nLineTextDistance;
             break;
-        case CTF_PM_FTN_LINE_WEIGTH:
+        case CTF_PM_FTN_LINE_WEIGHT:
             DBG_ASSERT( i == nIdx,
                         "received wrong property state index" );
             rState.maValue >>= nLineWeight;
diff --git a/xmloff/source/style/XMLFootnoteSeparatorImport.cxx 
b/xmloff/source/style/XMLFootnoteSeparatorImport.cxx
index 6b129d0..9926674 100644
--- a/xmloff/source/style/XMLFootnoteSeparatorImport.cxx
+++ b/xmloff/source/style/XMLFootnoteSeparatorImport.cxx
@@ -199,7 +199,7 @@
     XMLPropertyState aLineTextDistance( nIndex, aAny);
     rProperties.push_back(aLineTextDistance);
 
-    DBG_ASSERT( rMapper->FindEntryIndex(CTF_PM_FTN_LINE_WEIGTH) == nPropIndex,
+    DBG_ASSERT( rMapper->FindEntryIndex(CTF_PM_FTN_LINE_WEIGHT) == nPropIndex,
                 "Received wrong property map index!" );
     aAny <<= nLineWeight;
     XMLPropertyState aLineWeight( nPropIndex, aAny );

diff --git a/xmloff/inc/xmloff/xmltoken.hxx b/xmloff/inc/xmloff/xmltoken.hxx
index e19043a..a40da2c 100644
--- a/xmloff/inc/xmloff/xmltoken.hxx
+++ b/xmloff/inc/xmloff/xmltoken.hxx
@@ -3183,7 +3183,7 @@
         XML_HORIZONTAL_BAR,
         XML_VERTICAL_BAR,
 
-        XML_ERROR_STANDARD_WEIGTH, // errorbar standard deviation error weigth
+        XML_ERROR_STANDARD_WEIGHT, // errorbar standard deviation error weight
         XML_TOKEN_END
     };
 
-- 
To view, visit https://gerrit.libreoffice.org/3435
To unsubscribe, visit https://gerrit.libreoffice.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: Ie5dc62bf535360cde8a5ccd6f8be3965ff48739c
Gerrit-PatchSet: 1
Gerrit-Project: core
Gerrit-Branch: master
Gerrit-Owner: Lior Kaplan <kaplanlior@gmail.com>


Context


Privacy Policy | Impressum (Legal Info) | Copyright information: Unless otherwise specified, all text and images on this website are licensed under the Creative Commons Attribution-Share Alike 3.0 License. This does not include the source code of LibreOffice, which is licensed under the Mozilla Public License (MPLv2). "LibreOffice" and "The Document Foundation" are registered trademarks of their corresponding registered owners or are in actual use as trademarks in one or more countries. Their respective logos and icons are also subject to international copyright laws. Use thereof is explained in our trademark policy.